package org.jboss.errai.enterprise.client.jaxrs;

import com.google.gwt.core.client.GWT;
import com.google.gwt.http.client.Request;
import com.google.gwt.http.client.RequestBuilder;
import com.google.gwt.http.client.RequestCallback;
import com.google.gwt.http.client.RequestException;
import com.google.gwt.http.client.Response;
import com.google.gwt.http.client.URL;
import java.lang.annotation.Annotation;
import java.util.List;
import org.jboss.errai.bus.client.api.ErrorCallback;
import org.jboss.errai.bus.client.api.RemoteCallback;
import org.jboss.errai.bus.client.framework.ProxyProvider;
import org.jboss.errai.bus.client.framework.RemoteServiceProxyFactory;
import org.jboss.errai.enterprise.client.jaxrs.api.ResponseCallback;
import org.jboss.errai.enterprise.client.jaxrs.api.ResponseException;
import org.jboss.errai.enterprise.client.jaxrs.api.RestClient;
import org.jboss.testsample.model.Member;
import org.jboss.testsample.rest.MemberService;
import org.jboss.testsample.www.client.shared.Customer;
import org.jboss.testsample.www.client.shared.CustomerService;

public class JaxrsProxyLoaderImpl implements JaxrsProxyLoader {
  public void loadProxies() {
    class MemberServiceImpl implements MemberService, JaxrsProxy {
      private RemoteCallback remoteCallback;
      private ErrorCallback errorCallback;
      private String baseUrl;
      private List<Integer> successCodes;
      public void setQualifiers(Annotation[] annos) {

      }

      public void setErrorCallback(ErrorCallback callback) {
        errorCallback = callback;
      }

      public void setRemoteCallback(RemoteCallback callback) {
        remoteCallback = callback;
      }

      public void setSuccessCodes(List codes) {
        successCodes = codes;
      }

      public void setBaseUrl(String url) {
        baseUrl = url;
      }

      public String getBaseUrl() {
        if (baseUrl != null) {
          return baseUrl;
        } else {
          return RestClient.getApplicationRoot();
        }
      }

      private void handleError(Throwable throwable, Response response) {
        if (errorCallback != null) {
          errorCallback.error(null, throwable);
        } else if ((MemberServiceImpl.this.remoteCallback instanceof ResponseCallback) && (response != null)) {
          MemberServiceImpl.this.remoteCallback.callback(response);
        } else {
          GWT.log(throwable.getMessage(), throwable);
        }
      }

      public List listAllMembers() {
        StringBuilder url = new StringBuilder(getBaseUrl());
        url.append("members");
        RequestBuilder requestBuilder = new RequestBuilder(RequestBuilder.GET, url.toString());
        requestBuilder.setHeader("Accept", "application/json");
        try {
          requestBuilder.sendRequest(null, new RequestCallback() {
            public void onError(Request request, Throwable throwable) {
              MemberServiceImpl.this.handleError(throwable, null);
            }
            public void onResponseReceived(Request request, Response response) {
              if (((MemberServiceImpl.this.successCodes == null) || MemberServiceImpl.this.successCodes.contains(response.getStatusCode())) && ((response.getStatusCode() >= 200) && (response.getStatusCode() < 300))) {
                if (MemberServiceImpl.this.remoteCallback instanceof ResponseCallback) {
                  MemberServiceImpl.this.remoteCallback.callback(response);
                } else {
                  if (response.getStatusCode() == 204) {
                    MemberServiceImpl.this.remoteCallback.callback(null);
                  } else {
                    MemberServiceImpl.this.remoteCallback.callback(MarshallingWrapper.fromJSON(response.getText(), List.class, Member.class));
                  }
                }
              } else {
                ResponseException throwable = new ResponseException(response.getStatusText(), response);
                MemberServiceImpl.this.handleError(throwable, response);
              }
            }
          });
        } catch (RequestException throwable) {
          MemberServiceImpl.this.handleError(throwable, null);
        }
        return null;
      }

      public Member lookupMemberById(final long a0) {
        StringBuilder url = new StringBuilder(getBaseUrl());
        url.append("members/{id:[0-9][0-9]*}".replace("{id}", URL.encodePathSegment(new Long(a0).toString())));
        RequestBuilder requestBuilder = new RequestBuilder(RequestBuilder.GET, url.toString());
        requestBuilder.setHeader("Accept", "application/json");
        try {
          requestBuilder.sendRequest(null, new RequestCallback() {
            public void onError(Request request, Throwable throwable) {
              MemberServiceImpl.this.handleError(throwable, null);
            }
            public void onResponseReceived(Request request, Response response) {
              if (((MemberServiceImpl.this.successCodes == null) || MemberServiceImpl.this.successCodes.contains(response.getStatusCode())) && ((response.getStatusCode() >= 200) && (response.getStatusCode() < 300))) {
                if (MemberServiceImpl.this.remoteCallback instanceof ResponseCallback) {
                  MemberServiceImpl.this.remoteCallback.callback(response);
                } else {
                  if (response.getStatusCode() == 204) {
                    MemberServiceImpl.this.remoteCallback.callback(null);
                  } else {
                    MemberServiceImpl.this.remoteCallback.callback(MarshallingWrapper.fromJSON(response.getText(), Member.class, null));
                  }
                }
              } else {
                ResponseException throwable = new ResponseException(response.getStatusText(), response);
                MemberServiceImpl.this.handleError(throwable, response);
              }
            }
          });
        } catch (RequestException throwable) {
          MemberServiceImpl.this.handleError(throwable, null);
        }
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(MemberService.class, new ProxyProvider() {
      public Object getProxy() {
        return new MemberServiceImpl();
      }
    });
    class CustomerServiceImpl implements CustomerService, JaxrsProxy {
      private RemoteCallback remoteCallback;
      private ErrorCallback errorCallback;
      private String baseUrl;
      private List<Integer> successCodes;
      public void setQualifiers(Annotation[] annos) {

      }

      public void setErrorCallback(ErrorCallback callback) {
        errorCallback = callback;
      }

      public void setRemoteCallback(RemoteCallback callback) {
        remoteCallback = callback;
      }

      public void setSuccessCodes(List codes) {
        successCodes = codes;
      }

      public void setBaseUrl(String url) {
        baseUrl = url;
      }

      public String getBaseUrl() {
        if (baseUrl != null) {
          return baseUrl;
        } else {
          return RestClient.getApplicationRoot();
        }
      }

      private void handleError(Throwable throwable, Response response) {
        if (errorCallback != null) {
          errorCallback.error(null, throwable);
        } else if ((CustomerServiceImpl.this.remoteCallback instanceof ResponseCallback) && (response != null)) {
          CustomerServiceImpl.this.remoteCallback.callback(response);
        } else {
          GWT.log(throwable.getMessage(), throwable);
        }
      }

      public List listAllCustomers() {
        StringBuilder url = new StringBuilder(getBaseUrl());
        url.append("customers");
        RequestBuilder requestBuilder = new RequestBuilder(RequestBuilder.GET, url.toString());
        requestBuilder.setHeader("Accept", "application/json");
        try {
          requestBuilder.sendRequest(null, new RequestCallback() {
            public void onError(Request request, Throwable throwable) {
              CustomerServiceImpl.this.handleError(throwable, null);
            }
            public void onResponseReceived(Request request, Response response) {
              if (((CustomerServiceImpl.this.successCodes == null) || CustomerServiceImpl.this.successCodes.contains(response.getStatusCode())) && ((response.getStatusCode() >= 200) && (response.getStatusCode() < 300))) {
                if (CustomerServiceImpl.this.remoteCallback instanceof ResponseCallback) {
                  CustomerServiceImpl.this.remoteCallback.callback(response);
                } else {
                  if (response.getStatusCode() == 204) {
                    CustomerServiceImpl.this.remoteCallback.callback(null);
                  } else {
                    CustomerServiceImpl.this.remoteCallback.callback(MarshallingWrapper.fromJSON(response.getText(), List.class, Customer.class));
                  }
                }
              } else {
                ResponseException throwable = new ResponseException(response.getStatusText(), response);
                CustomerServiceImpl.this.handleError(throwable, response);
              }
            }
          });
        } catch (RequestException throwable) {
          CustomerServiceImpl.this.handleError(throwable, null);
        }
        return null;
      }

      public long createCustomer(final Customer a0) {
        StringBuilder url = new StringBuilder(getBaseUrl());
        url.append("customers");
        RequestBuilder requestBuilder = new RequestBuilder(RequestBuilder.POST, url.toString());
        requestBuilder.setHeader("Accept", "text/plain");
        requestBuilder.setHeader("Content-Type", "application/json");
        try {
          requestBuilder.sendRequest(MarshallingWrapper.toJSON(a0), new RequestCallback() {
            public void onError(Request request, Throwable throwable) {
              CustomerServiceImpl.this.handleError(throwable, null);
            }
            public void onResponseReceived(Request request, Response response) {
              if (((CustomerServiceImpl.this.successCodes == null) || CustomerServiceImpl.this.successCodes.contains(response.getStatusCode())) && ((response.getStatusCode() >= 200) && (response.getStatusCode() < 300))) {
                if (CustomerServiceImpl.this.remoteCallback instanceof ResponseCallback) {
                  CustomerServiceImpl.this.remoteCallback.callback(response);
                } else {
                  if (response.getStatusCode() == 204) {
                    CustomerServiceImpl.this.remoteCallback.callback(null);
                  } else {
                    CustomerServiceImpl.this.remoteCallback.callback(Long.valueOf(response.getText()));
                  }
                }
              } else {
                ResponseException throwable = new ResponseException(response.getStatusText(), response);
                CustomerServiceImpl.this.handleError(throwable, response);
              }
            }
          });
        } catch (RequestException throwable) {
          CustomerServiceImpl.this.handleError(throwable, null);
        }
        return 0L;
      }

      public Customer updateCustomer(final long a0, final Customer a1) {
        StringBuilder url = new StringBuilder(getBaseUrl());
        url.append("customers/{id}".replace("{id}", URL.encodePathSegment(new Long(a0).toString())));
        RequestBuilder requestBuilder = new RequestBuilder(RequestBuilder.PUT, url.toString());
        requestBuilder.setHeader("Accept", "application/json");
        requestBuilder.setHeader("Content-Type", "application/json");
        try {
          requestBuilder.sendRequest(MarshallingWrapper.toJSON(a1), new RequestCallback() {
            public void onError(Request request, Throwable throwable) {
              CustomerServiceImpl.this.handleError(throwable, null);
            }
            public void onResponseReceived(Request request, Response response) {
              if (((CustomerServiceImpl.this.successCodes == null) || CustomerServiceImpl.this.successCodes.contains(response.getStatusCode())) && ((response.getStatusCode() >= 200) && (response.getStatusCode() < 300))) {
                if (CustomerServiceImpl.this.remoteCallback instanceof ResponseCallback) {
                  CustomerServiceImpl.this.remoteCallback.callback(response);
                } else {
                  if (response.getStatusCode() == 204) {
                    CustomerServiceImpl.this.remoteCallback.callback(null);
                  } else {
                    CustomerServiceImpl.this.remoteCallback.callback(MarshallingWrapper.fromJSON(response.getText(), Customer.class, null));
                  }
                }
              } else {
                ResponseException throwable = new ResponseException(response.getStatusText(), response);
                CustomerServiceImpl.this.handleError(throwable, response);
              }
            }
          });
        } catch (RequestException throwable) {
          CustomerServiceImpl.this.handleError(throwable, null);
        }
        return null;
      }

      public void deleteCustomer(final long a0) {
        StringBuilder url = new StringBuilder(getBaseUrl());
        url.append("customers/{id}".replace("{id}", URL.encodePathSegment(new Long(a0).toString())));
        RequestBuilder requestBuilder = new RequestBuilder(RequestBuilder.DELETE, url.toString());
        try {
          requestBuilder.sendRequest(null, new RequestCallback() {
            public void onError(Request request, Throwable throwable) {
              CustomerServiceImpl.this.handleError(throwable, null);
            }
            public void onResponseReceived(Request request, Response response) {
              if (((CustomerServiceImpl.this.successCodes == null) || CustomerServiceImpl.this.successCodes.contains(response.getStatusCode())) && ((response.getStatusCode() >= 200) && (response.getStatusCode() < 300))) {
                if (CustomerServiceImpl.this.remoteCallback instanceof ResponseCallback) {
                  CustomerServiceImpl.this.remoteCallback.callback(response);
                } else {
                  if (response.getStatusCode() == 204) {
                    CustomerServiceImpl.this.remoteCallback.callback(null);
                  } else {
                    CustomerServiceImpl.this.remoteCallback.callback(null);
                  }
                }
              } else {
                ResponseException throwable = new ResponseException(response.getStatusText(), response);
                CustomerServiceImpl.this.handleError(throwable, response);
              }
            }
          });
        } catch (RequestException throwable) {
          CustomerServiceImpl.this.handleError(throwable, null);
        }
      }

      public Customer retrieveCustomerById(final long a0) {
        StringBuilder url = new StringBuilder(getBaseUrl());
        url.append("customers/{id}".replace("{id}", URL.encodePathSegment(new Long(a0).toString())));
        RequestBuilder requestBuilder = new RequestBuilder(RequestBuilder.GET, url.toString());
        requestBuilder.setHeader("Accept", "application/json");
        try {
          requestBuilder.sendRequest(null, new RequestCallback() {
            public void onError(Request request, Throwable throwable) {
              CustomerServiceImpl.this.handleError(throwable, null);
            }
            public void onResponseReceived(Request request, Response response) {
              if (((CustomerServiceImpl.this.successCodes == null) || CustomerServiceImpl.this.successCodes.contains(response.getStatusCode())) && ((response.getStatusCode() >= 200) && (response.getStatusCode() < 300))) {
                if (CustomerServiceImpl.this.remoteCallback instanceof ResponseCallback) {
                  CustomerServiceImpl.this.remoteCallback.callback(response);
                } else {
                  if (response.getStatusCode() == 204) {
                    CustomerServiceImpl.this.remoteCallback.callback(null);
                  } else {
                    CustomerServiceImpl.this.remoteCallback.callback(MarshallingWrapper.fromJSON(response.getText(), Customer.class, null));
                  }
                }
              } else {
                ResponseException throwable = new ResponseException(response.getStatusText(), response);
                CustomerServiceImpl.this.handleError(throwable, response);
              }
            }
          });
        } catch (RequestException throwable) {
          CustomerServiceImpl.this.handleError(throwable, null);
        }
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(CustomerService.class, new ProxyProvider() {
      public Object getProxy() {
        return new CustomerServiceImpl();
      }
    });
  }
}